@@ -51,8 +51,11 @@ test_that('Test event adding', {
     hm <- loadPamguardBinaryFile(bin)
     uids <- c(4000001, 4000002, 4000004)
     addPgEvent(db = tmpDb, UIDs = uids, binary = bin, eventType = 'MyNewEvent')
+    addPgEvent(db = tmpDb, UIDs = uids, binary = bin, eventType = 'MyNewEvent')
+
     con <- dbConnect(tmpDb, drv=SQLite())
     ev <- dbReadTable(con, 'Click_Detector_OfflineEvents')
+    expect_equal(nrow(ev), 1)
     click <- dbReadTable(con, 'Click_Detector_OfflineClicks')
     lookup <- dbReadTable(con, 'Lookup')
     # test matching data got added
@@ -74,3 +77,22 @@ test_that('Test event adding', {
     unlink(tmpDb)
     expect_true(!file.exists(tmpDb))
 })
+
+test_that('Test update UID', {
+    db <- system.file('extdata', 'ExBadUID.sqlite3', package='PAMmisc')
+    td <- tempdir()
+    file.copy(from = db, to = td)
+    tmpDb <- file.path(td, basename(db))
+    expect_true(file.exists(tmpDb))
+    goodUIDs <- c(8000003, 529000024, 529000026, 386000022, 529000027)
+    bin <- system.file('extdata', 'Binaries', package='PAMmisc')
+    nUpd <- updateUID(tmpDb, bin, verbose=FALSE, progress=FALSE)
+    expect_equal(nUpd$nAdded[[1]], 5)
+    con <- dbConnect(tmpDb, drv=SQLite())
+    det <- dbReadTable(con, 'Click_Detector_OfflineClicks')
+    expect_equal(det$newUID[1:5], goodUIDs)
+    expect_equal(det$newUID[6:26], det$UID[6:26])
+    dbDisconnect(con)
+    unlink(tmpDb)
+    expect_true(!file.exists(tmpDb))
+})
